==> StudentGWAS_0.0.3.tar.gz: StudentGWAS/man/GWASdata-class.Rd <==
\name{GWASdata-class}
\docType{class}

\alias{GWASdata-class}
\alias{GWASdata}
\alias{datapath}
\alias{datapath,GWASdata-method}
\alias{dataconn}
\alias{dataconn,GWASdata-method}
\alias{metadatapath}
\alias{metadatapath,GWASdata-method}
\alias{metadataconn}
\alias{metadataconn,GWASdata-method}
\alias{nrow,GWASdata-method}
\alias{ncol,GWASdata-method}
\alias{dim,GWASdata-method}
\alias{coerce,GWASdata,matrix-method}
\alias{getCols}
\alias{getCols,GWASdata-method}
\alias{as.matrix,GWASdata-method}

\alias{show,GWASdata-method}

\title{GWASdata objects}

\description{
  The GWASdata class is a container for storing the experimental data
  from a Genome-wide association study together with the metadata
  associated with the subjects and SNPs involved in the study.
}


\section{Constructor}{
  \describe{
    \item{}{
      \code{GWASdata(datapath, metadatapath)}:

      \code{datapath} must be the path to a NetCDF file containing the
      GWAS experimental data. The NetCDF file must contain a variable called
      "snpData" which must be a matrix of bytes with 1 row per subject
      and 1 col per SNP. The names of the 2 dimensions must be "subjectDim"
      and "snpDim".
      The byte values must be: 0 for missing, 1 for homozygous major (A/A),
      2 for heterozygous (A/B), 3 for homozygous minor (B/B).

      \code{metadatapath} must be the path to an SQLite db file containing
      the GWAS metadata. This db must contain (at least) 2 tables: 'subjects'
      and 'snps'.
      The 'subjects' table must have 1 row per subject involved in the GWAS
      and the following columns (not necessarily in this order):
      \itemize{
        \item 'id': INTEGER, the primary key, ranging from 1 to the nb of
                    subjects in the study.
        \item 'subject_id': TEXT, a unique string id.
        \item 'case_control': TEXT, "case" or "control".
      }
      The 'snps' table must have 1 row per SNP in the study and the following
      columns (not necessarily in this order):
      \itemize{
        \item 'id': INTEGER, the primary key, ranging from 1 to the nb of
                    SNPs in the study.
        \item 'snp_id': TEXT, the (unique) ref SNP id of the SNP.
        \item 'seqnames': TEXT, the name of the chromosome (or sequence)
              the SNP belongs to.
        \item 'start': INTEGER, the 1-based position of the SNP relative
              to the 5' end of the positive strand of the chromosome.
        \item 'gene_id': TEXT, an Entrez Gene ID if the SNP "belongs" to
              a gene, or NULL if it doesn't.
      }

      The \code{GWASdata} constructor creates and returns a GWASdata
      instance pointing to those 2 files.
    }
  }
}

\section{Accessors}{
  In the code snippets below, \code{x} is a GWASdata object.

  \describe{
    \item{}{
      \code{datapath(x)}: The path to the NetCDF file containing the
      GWAS experimental data. See the \code{GWASdata} constructor above.
    }
    \item{}{
      \code{dataconn(x)}: A connection object to the NetCDF file.
    }
    \item{}{
      \code{metadatapath(x)}: The path to the SQLite db file containing
      the GWAS metadata. See the \code{GWASdata} constructor above.
    }
    \item{}{
      \code{metadataconn(x)}: A connection object to the SQLite file.
    }
    \item{}{
      \code{nrow(x)}: The number of subjects.
    }
    \item{}{
      \code{ncol(x)}: The number of SNPs.
    }
    \item{}{
      \code{dim(x)}: Defined as \code{c(nrow(x), ncol(x))}.
    }
    \item{}{
      \code{getCols(x, first, last = first)}:
      Extract the columns of data with indices in the range (first,last).
      The result is a raw matrix if the number of extracted columns is >= 2,
      otherwise it is a raw vector.
    }
  }
}

\section{Coercion}{
  In the code snippets below, \code{x} is a GWASdata object.

  \describe{
    \item{}{
      \code{as(x, "matrix")}, \code{as.matrix(x)}:
      Turns \code{x} into a raw matrix.
    }
  }
}

\author{Student Name}

\seealso{
  \code{\link{cld}} for composite linkage disequlibrum calculation.
}

\examples{
  ## Constructor:
  datapath <- system.file("extdata", "small_snpData.nc",
                           package="StudentGWAS")
  metadatapath <- system.file("extdata", "small_metadata.sqlite",
                               package="StudentGWAS")
  gwas <- GWASdata(datapath, metadatapath)
  gwas

  ## Accessors:
  dim(gwas)
  datapath(gwas)
  dataconn(gwas)  # an "ncdf" object (S3 class)
  metadatapath(gwas)
  metadataconn(gwas)  # an SQLiteConnection object
  getCols(gwas, 2)
  getCols(gwas, 1, 4)

  ## Coercion:
  as.matrix(gwas)
}

\keyword{methods}
\keyword{classes}

==> StudentGWAS_0.3.0.tar.gz: StudentGWAS/man/GWASdata-class.Rd <==
\name{GWASdata-class}
\docType{class}

\alias{GWASdata-class}
\alias{GWASdata}
\alias{datapath}
\alias{datapath,GWASdata-method}
\alias{dataconn}
\alias{dataconn,GWASdata-method}
\alias{metadatapath}
\alias{metadatapath,GWASdata-method}
\alias{metadataconn}
\alias{metadataconn,GWASdata-method}
\alias{nrow,GWASdata-method}
\alias{ncol,GWASdata-method}
\alias{dim,GWASdata-method}
\alias{coerce,GWASdata,matrix-method}
\alias{getCols}
\alias{getCols,GWASdata-method}
\alias{as.matrix,GWASdata-method}

\alias{show,GWASdata-method}

\title{GWASdata objects}

\description{
  The GWASdata class is a container for storing the experimental data
  from a genome-wide association study together with the metadata
  associated with the subjects and SNPs involved in the study.
}


\section{Constructor}{
  \describe{
    \item{}{
      \code{GWASdata(datapath, metadatapath)}:

      \code{datapath} must be the path to a NetCDF file containing the
      GWAS experimental data. The NetCDF file must contain a variable called
      "snpData" which must be a matrix of bytes with 1 row per subject
      and 1 col per SNP. The names of the 2 dimensions must be "subjectDim"
      and "snpDim".
      The byte values must be: 0 for missing, 1 for homozygous major (A/A),
      2 for heterozygous (A/B), 3 for homozygous minor (B/B).

      \code{metadatapath} must be the path to an SQLite db file containing
      the GWAS metadata. This db must contain (at least) 2 tables: 'subjects'
      and 'snps'.
      The 'subjects' table must have 1 row per subject involved in the GWAS
      and the following columns (not necessarily in this order):
      \itemize{
        \item 'id': INTEGER, the primary key, ranging from 1 to the nb of
                    subjects in the study.
        \item 'subject_id': TEXT, a unique string id.
        \item 'case_control': TEXT, "case" or "control".
      }
      The 'snps' table must have 1 row per SNP in the study and the following
      columns (not necessarily in this order):
      \itemize{
        \item 'id': INTEGER, the primary key, ranging from 1 to the nb of
                    SNPs in the study.
        \item 'snp_id': TEXT, the (unique) ref SNP id of the SNP.
        \item 'seqnames': TEXT, the name of the chromosome (or sequence)
              the SNP belongs to.
        \item 'start': INTEGER, the 1-based position of the SNP relative
              to the 5' end of the positive strand of the chromosome.
        \item 'gene_id': TEXT, an Entrez Gene ID if the SNP "belongs" to
              a gene, or NULL if it doesn't.
      }

      The \code{GWASdata} constructor creates and returns a GWASdata
      instance pointing to those 2 files.
    }
  }
}

\section{Accessors}{
  In the code snippets below, \code{x} is a GWASdata object.

  \describe{
    \item{}{
      \code{datapath(x)}: The path to the NetCDF file containing the
      GWAS experimental data. See the \code{GWASdata} constructor above.
    }
    \item{}{
      \code{dataconn(x)}: A connection object to the NetCDF file.
    }
    \item{}{
      \code{metadatapath(x)}: The path to the SQLite db file containing
      the GWAS metadata. See the \code{GWASdata} constructor above.
    }
    \item{}{
      \code{metadataconn(x)}: A connection object to the SQLite file.
    }
    \item{}{
      \code{nrow(x)}: The number of subjects.
    }
    \item{}{
      \code{ncol(x)}: The number of SNPs.
    }
    \item{}{
      \code{dim(x)}: Defined as \code{c(nrow(x), ncol(x))}.
    }
    \item{}{
      \code{getCols(x, first, last = first)}:
      Extract the columns of data with indices in the range (first,last).
      The result is a raw matrix if the number of extracted columns is >= 2,
      otherwise it is a raw vector.
    }
  }
}

\section{Coercion}{
  In the code snippets below, \code{x} is a GWASdata object.

  \describe{
    \item{}{
      \code{as(x, "matrix")}, \code{as.matrix(x)}:
      Turns \code{x} into a raw matrix.
    }
  }
}

\author{Student Name}

\examples{
  ## Constructor:
  datapath <- system.file("extdata", "small_snpData.nc",
                           package="StudentGWAS")
  metadatapath <- system.file("extdata", "small_metadata.sqlite",
                               package="StudentGWAS")
  gwas <- GWASdata(datapath, metadatapath)
  gwas

  ## Accessors:
  dim(gwas)
  datapath(gwas)
  dataconn(gwas)  # an "ncdf" object (S3 class)
  metadatapath(gwas)
  metadataconn(gwas)  # an SQLiteConnection object
  getCols(gwas, 2)
  getCols(gwas, 1, 4)

  ## Coercion:
  as.matrix(gwas)
}

\keyword{methods}
\keyword{classes}
